# Effmap_demo

Effmap_demo is the python library, which demonstrates the use of the hydro-static transmission (HST) and regression model (Regressor) classses intriduced in effmap.

## How to use
```
pip install effmap
streamlit run effmap_demo.py
```
